﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace LoadPointData
{
    public partial class Form1 : Form
    {
        private LayerOverlay layerOverlay;
        private static readonly string shapefileFilePath = @"../../App_Data/sulingen.shp";
        private static readonly string featureCountFormat = "Features Count: {0}";

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            ShapeFileFeatureLayer shpLayer = new ShapeFileFeatureLayer(shapefileFilePath);

            shpLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.LightBlue, 5);
            shpLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(shpLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            shpLayer.Open();
            winformsMap1.CurrentExtent = shpLayer.GetBoundingBox();

            winformsMap1.Refresh();

            label1.Text = string.Format(featureCountFormat, shpLayer.FeatureSource.GetCount());
        }

        private void button1_Click(object sender, EventArgs e)
        {
            ShapeFileFeatureLayer shpLayer = new ShapeFileFeatureLayer(shapefileFilePath);
            layerOverlay.Layers.Clear();
            layerOverlay.Layers.Add(shpLayer);

            if (button1.Text == "Switch Style To Cross")
            {
                shpLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Cross, GeoColor.StandardColors.LightBlue, 5);
                shpLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                button1.Text = "Switch Style To Circle";
            }
            else
            {
                shpLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.LightBlue, 5);
                shpLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                button1.Text = "Switch Style To Cross";
            }

            winformsMap1.Refresh();
            label1.Text = string.Format(featureCountFormat, shpLayer.FeatureSource.GetCount());
        }
    }
}